/*!
 * Built with Stencil
 * By PostNord.
 */
'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

const index = require('./index-ec4ed1cc.js');
const arrow_left = require('./arrow_left-d8f2c601.js');
const arrow_right = require('./arrow_right-8a1192e2.js');
const helpers = require('./helpers-2e2349b4.js');

const translations = {
    PAGINATION: {
        sv: 'Paginering',
        en: 'Pagination',
        da: 'Paginering',
        fi: 'Sivunumerointi',
        no: 'Paginering',
    },
    PAGE: {
        sv: 'Sida',
        en: 'Page',
        da: 'Side',
        fi: 'Sivu',
        no: 'Side',
    },
    PREVIOUS_PAGE: {
        sv: 'Föregående sida',
        en: 'Previous page',
        da: 'Forrige side',
        fi: 'Edellinen sivu',
        no: 'Forrige side',
    },
    NEXT_PAGE: {
        sv: 'Nästa sida',
        en: 'Next page',
        da: 'Næste side',
        fi: 'Seuraava sivu',
        no: 'Neste side',
    },
    ROWS_PAGE: {
        sv: 'Object per sida',
        en: 'Items per page',
        da: 'Varer pr. side',
        fi: 'Kohteita per sivu',
        no: 'Elementer per side',
    },
};

const pnPaginationCss = "pn-pagination{display:block;margin-top:1.5em}pn-pagination .pn-pagination{display:flex;gap:1em;flex-wrap:wrap;padding-top:1em;border-top:0.0625em solid #e9e6e5}pn-pagination .pn-pagination-container{display:flex;align-items:center;flex-wrap:wrap;gap:0.5em;margin:0 auto}pn-pagination .pn-pagination-container[data-right]{margin-right:0}pn-pagination .pn-pagination-container>[data-arrow]{display:none}pn-pagination .pn-pagination-container>[data-arrow][data-show]{display:inline-block}pn-pagination .pn-pagination-rows{flex:0 0 auto;margin-right:auto}pn-pagination .pn-pagination-pages{flex:0 0 auto;margin-left:auto}pn-pagination .pn-pagination-list{list-style:none;padding:0;margin:0;display:flex;flex-wrap:wrap;justify-content:center;gap:0.5em}pn-pagination .pn-pagination-list pn-button>.pn-button{padding:0.375em 0.75em}pn-pagination .pn-pagination-dot{display:none;padding:0.375em 0.5em;height:2em;width:2.5em;text-align:center}pn-pagination .pn-pagination-dot[data-show]{display:inline-block}";
const PnPaginationStyle0 = pnPaginationCss;

const PnPagination = class {
    constructor(hostRef) {
        index.registerInstance(this, hostRef);
        this.pageSelected = index.createEvent(this, "pageSelected", 7);
        this.rowsSelected = index.createEvent(this, "rowsSelected", 7);
        this.list = undefined;
        this.label = undefined;
        this.urlTemplate = '?page={page}';
        this.paginationId = null;
        this.language = null;
        this.page = 1;
        this.pages = undefined;
        this.pagesVisible = 5;
        this.rows = null;
        this.rowsList = '10,25,50';
        this.rowsLabel = null;
    }
    listElement;
    get hostElement() { return index.getElement(this); }
    handlePage() {
        if (this.page > this.pages)
            this.page = this.pages;
        else if (this.page < 1)
            this.page = 1;
    }
    handlePages() {
        const list = [];
        if (this.pages > 10000) {
            console.error(`${this.hostElement.localName}: Invalid page count ${this.pages}. Maximum is 10000.`);
            this.pages = 10000;
        }
        for (let index = 0; this.pages > index; index++) {
            const page = index + 1;
            list.push({ index, page });
        }
        this.list = list;
        this.handlePage();
    }
    handlePagesVisible() {
        if (5 > this.pagesVisible)
            this.pagesVisible = 5;
        if (this.pagesVisible % 2 === 0)
            this.pagesVisible = Math.round(this.pagesVisible) - 1;
    }
    /** Emitted when the page is changed. Either via clicking a link or selecting a page in the select. */
    pageSelected;
    /** This event fires when the user changes how many items should be shown per page. */
    rowsSelected;
    async componentWillLoad() {
        this.handlePagesVisible();
        this.handlePages();
        if (this.language === null)
            await helpers.awaitTopbar(this.hostElement);
    }
    translate(prop) {
        return translations[prop][this.language || helpers.en];
    }
    isActivePage(page) {
        return page === this.page;
    }
    navigate({ page, event, focus }) {
        if (typeof page === 'number' && page >= 1 && this.pages >= page)
            this.page = page;
        this.pageSelected.emit({ page: this.page, mouse: event });
        if (focus)
            requestAnimationFrame(() => {
                const element = this.listElement.querySelector('a[aria-current="page"]');
                element?.focus({ preventScroll: true });
            });
    }
    useRowList() {
        return !!this.rows && !!this.rowsList;
    }
    setRows(event) {
        const target = event.target;
        this.rows = Number(target.value);
        this.rowsSelected.emit({ rows: this.rows, change: event });
    }
    getRowList() {
        return this.rowsList.split(',').map(item => Number(item.trim()));
    }
    /** Get the page numbers of the lowest and highest visible page. */
    getPaginationIndex() {
        const current = this.page;
        let low = current - Math.ceil(this.pagesVisible / 2);
        let high = current + Math.floor(this.pagesVisible / 2);
        for (let i = 0; this.pagesVisible > i; i++) {
            if (low < 0) {
                high++;
                low++;
            }
            else if (high > this.pages) {
                high--;
                low--;
            }
        }
        const lowest = 0 > low ? 0 : low;
        const leftIndent = lowest >= 1;
        const rightIndent = this.pages > high;
        return {
            low: rightIndent && leftIndent ? lowest + 1 : lowest,
            high: rightIndent && leftIndent ? high - 1 : high,
            leftIndent,
            rightIndent,
        };
    }
    getPagination() {
        const { low, high } = this.getPaginationIndex();
        return this.list.slice(low, high);
    }
    getUrl(page) {
        return this.setPageText(this.urlTemplate, page);
    }
    setPageText(text, page) {
        return text.replace('{page}', page.toString());
    }
    getPrevPage() {
        let page = this.page;
        return page > 1 ? (page -= 1) : 1;
    }
    getNextPage() {
        let page = this.page;
        return this.pages > page ? (page += 1) : this.pages;
    }
    showIntendation(last = false) {
        const { leftIndent, rightIndent } = this.getPaginationIndex();
        return last ? rightIndent : leftIndent;
    }
    renderDivider(last = false) {
        return (index.h("span", { class: "pn-pagination-dot", "data-show": this.showIntendation(last) }, "..."));
    }
    renderButton({ page, dataAttr }) {
        const active = this.isActivePage(page);
        return (index.h("pn-button", { label: page.toString(), arialabel: `${this.translate('PAGE')} ${page}`, ariacurrent: active ? 'page' : null, href: this.getUrl(page), variant: active ? 'outlined' : '', appearance: "light", small: true, "data-arrow": dataAttr, "data-show": dataAttr && this.showIntendation(dataAttr === 'last'), onPnClick: ({ detail }) => this.navigate({ page, event: detail, focus: true }) }));
    }
    renderItem({ page }) {
        return (index.h("li", { class: "pn-pagination-list-item", "aria-setsize": this.pages, "aria-posinset": page }, this.renderButton({ page })));
    }
    renderJumpButton(last = false) {
        const rel = last ? 'next' : 'prev';
        const icon = last ? arrow_right.arrow_right : arrow_left.arrow_left;
        const page = last ? this.getNextPage() : this.getPrevPage();
        const current = last ? this.pages === this.page : 1 === this.page;
        const text = last ? 'NEXT_PAGE' : 'PREVIOUS_PAGE';
        const showPageNumber = current ? '' : ` (${page})`;
        const label = `${this.translate(text)}${showPageNumber}`;
        return (index.h("pn-button", { arialabel: label, ariacurrent: current ? 'page' : null, href: this.getUrl(page), rel: current ? null : rel, appearance: "light", small: true, icon: icon, iconOnly: true, onPnClick: ({ detail }) => this.navigate({ page, event: detail }) }));
    }
    render() {
        return (index.h(index.Host, { key: '8ef71bfb27f4e5e09ec869ca2f4984a213a49665' }, index.h("nav", { key: '0b970ff49f4d0c340eebc900c4a69700c9948c3e', id: this.paginationId, class: "pn-pagination", "aria-label": this.label || this.translate('PAGINATION') }, this.useRowList() && (index.h("pn-select", { key: '21112276ee5128107dddc4296f1b46f0aa40ef0a', class: "pn-pagination-rows", label: this.rowsLabel || this.translate('ROWS_PAGE'), onChange: event => this.setRows(event) }, this.getRowList().map(item => (index.h("option", { value: item, selected: this.rows === Number(item), innerHTML: `${item}` }))))), index.h("div", { key: '69eca7ba22dadc8b370384af2084e6caeeef6ef5', class: "pn-pagination-container", "data-right": this.useRowList() }, this.renderJumpButton(), this.renderButton({ page: 1, dataAttr: 'first' }), this.renderDivider(), index.h("ol", { key: '1d4587a57f2b2914105a33f97cde5ebae0ef41dd', class: "pn-pagination-list", ref: el => (this.listElement = el) }, this.getPagination().map(item => this.renderItem(item))), this.renderDivider(true), this.renderButton({ page: this.pages, dataAttr: 'last' }), this.renderJumpButton(true)))));
    }
    static get watchers() { return {
        "page": ["handlePage"],
        "pages": ["handlePages"],
        "pagesVisible": ["handlePagesVisible"]
    }; }
};
PnPagination.style = PnPaginationStyle0;

exports.pn_pagination = PnPagination;

//# sourceMappingURL=pn-pagination.cjs.entry.js.map