/*!
 * Built with Stencil
 * By PostNord.
 */
import { h, Host } from "@stencil/core";
/** The `pn-tag` is a non-interactive visual marker designed to emphasize important aspects of an item, such as its status. */
export class PnTag {
    constructor() {
        this.label = undefined;
        this.icon = undefined;
        this.appearance = '';
        this.dark = false;
        this.large = false;
        this.small = false;
        this.xsmall = false;
    }
    componentWillRender() {
        if (!!this.icon && this.xsmall)
            console.warn(`pn-tag: Icon was not rendered because tag size is set to xsmall`);
    }
    showIcon() {
        return !!this.icon && !this.xsmall;
    }
    render() {
        return (h(Host, { key: 'f07d506fb9d4df01931b4ac381c424a904a90c1f' }, h("div", { key: '88bce171adea43125fc3de310016b245ac509407', class: "pn-tag", "data-appearance": this.appearance, "data-icon": !!this.icon, "data-dark": this.dark, "data-small": this.small, "data-xsmall": this.xsmall, "data-large": this.large }, this.showIcon() && h("pn-icon", { key: '11b7548ee1427d38edd5af4535ad67a4099b6ae1', icon: this.icon }), h("span", { key: 'b3d51d7762cb36c40eaa5824dcdf575ce2484186', class: "pn-tag-label" }, this.label))));
    }
    static get is() { return "pn-tag"; }
    static get originalStyleUrls() {
        return {
            "$": ["pn-tag.scss"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["pn-tag.css"]
        };
    }
    static get properties() {
        return {
            "label": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": true,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "The label of the tag."
                },
                "attribute": "label",
                "reflect": false
            },
            "icon": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [{
                            "name": "see",
                            "text": "{@link https://portal.postnord.com/web-components/?path=/docs/docs-assets--docs Get started with PostNord assets.}"
                        }],
                    "text": "Select icon from out `pn-design-assets` list. Works with any SVG content.\n\n**Please note**: Can not be used with the `xsmall` prop due to the small size."
                },
                "attribute": "icon",
                "reflect": false
            },
            "appearance": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "'' | 'discrete' | 'positive' | 'warning' | 'error'",
                    "resolved": "\"\" | \"discrete\" | \"error\" | \"positive\" | \"warning\"",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [{
                            "name": "category",
                            "text": "Visual"
                        }],
                    "text": "Set tag appearance: `discrete`, `positive`, `warning` & `error`."
                },
                "attribute": "appearance",
                "reflect": false,
                "defaultValue": "''"
            },
            "dark": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [{
                            "name": "category",
                            "text": "Visual"
                        }, {
                            "name": "deprecated",
                            "text": "Will be removed in v8.0.0"
                        }],
                    "text": "Set darker background-color on the tag.\n\nThis is intended for better tag visibility on colored background."
                },
                "attribute": "dark",
                "reflect": false,
                "defaultValue": "false"
            },
            "large": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [{
                            "name": "category",
                            "text": "Size"
                        }],
                    "text": "Set larger tag."
                },
                "attribute": "large",
                "reflect": false,
                "defaultValue": "false"
            },
            "small": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [{
                            "name": "category",
                            "text": "Size"
                        }],
                    "text": "Set smaller tag."
                },
                "attribute": "small",
                "reflect": false,
                "defaultValue": "false"
            },
            "xsmall": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [{
                            "name": "category",
                            "text": "Size"
                        }],
                    "text": "Set extra small tag."
                },
                "attribute": "xsmall",
                "reflect": false,
                "defaultValue": "false"
            }
        };
    }
}
//# sourceMappingURL=pn-tag.js.map
