/*!
 * Built with Stencil
 * By PostNord.
 */
import { Host, h } from "@stencil/core";
import { arrow_right, open_in_new } from "pn-design-assets/pn-assets/icons.js";
import { ripple, uuidv4 } from "../../../index";
/**
 * The card component is more than just a navigational element.
 * It is a flexible component that can be used as a product item, a clickable link card, etc...
 *
 * Setting the `href` prop will transform the entire `pn-card` into a clickable element.
 * If you need content to be interactable inside the card, do not use the `href` prop.
 *
 * @slot - The default slot is the primary content of the card. This is the same area where the `text` prop is located.
 * @slot image - Set a custom image/svg/illustration. Simply use an `img` tag with the slot "image".
 * @slot tags - Add `pn-tags` that will be positioned above the `label` and `overline` if used.
 * @slot header - The header content, same area that the `label` and `overline` props will appear.
 * @slot navigation - This slot is intended for one or more `pn-button` components.
 * Only use **without** the `href` prop. Having both at the same time makes the component inaccessible.
 */
export class PnCard {
    constructor() {
        this.visibleOutline = false;
        this.label = undefined;
        this.labelTag = 'h3';
        this.overline = undefined;
        this.text = undefined;
        this.cardId = null;
        this.horizontal = false;
        this.reverse = false;
        this.aspectRatio = '';
        this.href = undefined;
        this.hrefLabel = undefined;
        this.target = undefined;
        this.rel = 'noopener noreferrer';
        this.icon = null;
    }
    id = `pn-card-${uuidv4()}`;
    idTitle = `${this.id}-title`;
    hostElement;
    watchCardId() {
        const id = this.cardId || this.id;
        this.idTitle = `${id}-title`;
    }
    /** Emitted when you click on the card link (if you use the `href` prop). */
    pnCard;
    componentWillLoad() {
        this.watchCardId();
    }
    isExternal() {
        return this.target === '_blank';
    }
    showTitle() {
        return !!this.label;
    }
    showHref() {
        return !!this.href && (this.hrefLabel || this.showTitle());
    }
    getTitleId() {
        return this.hrefLabel ? null : this.idTitle;
    }
    getLabelledby() {
        return this.hrefLabel ? null : this.showTitle() ? this.idTitle : null;
    }
    getIcon() {
        if (!!this.icon)
            return this.icon;
        return this.isExternal() ? open_in_new : arrow_right;
    }
    getHeadingTag() {
        const tags = ['h2', 'h3', 'h4', 'h5', 'h6', 'p'];
        return tags.includes(this.labelTag) ? this.labelTag : 'h3';
    }
    handleFocus({ type, target }) {
        this.visibleOutline = type === 'focus' && target.matches(':focus-visible');
    }
    handleClick(event) {
        ripple(event, this.hostElement, '.pn-card');
        this.pnCard.emit({ click: event });
    }
    render() {
        const TitleTag = this.getHeadingTag();
        return (h(Host, { key: '5059ced25e86a6fe205d470bf3591cd971adf8f1' }, h("article", { key: 'f1135d78ed76c1bbd4c2f4064d83d0df93aca339', id: this.cardId, class: "pn-card", "data-link": !!this.href, "data-horizontal": this.horizontal, "data-reverse": this.reverse, "data-focus": this.visibleOutline }, h("div", { key: 'c2ee9fa9314c19d40ad7725866dddfdd41bde019', class: "pn-card-image" }, h("picture", { key: '75b53ffaf62275459085540c4670801f20c943b5', class: "pn-card-picture", style: { '--pn-card-aspect-ratio': this.aspectRatio || 'unset' } }, h("slot", { key: '83a17d8a5c675d0b6e22a6683c697fce689a901c', name: "image" }))), h("div", { key: '8939d981a52f0802fd39e2fec5e9b430aa0d0d7e', class: "pn-card-content" }, h("header", { key: 'ba23d81d3f9d1770a94625db39ef10b79f52e588', class: "pn-card-header" }, h("div", { key: '4ac22c93173cde6cee1bd05557322733e6a1a358', class: "pn-card-tags" }, h("slot", { key: 'a9764743f78b34dbe4762ab5e7f7df5812bff9a0', name: "tags" })), !!this.overline && h("p", { key: '5b931af9c1d702439c3d7044549a8a0b721d0732', class: "pn-card-label-overline" }, this.overline), !!this.label && (h(TitleTag, { key: 'f431c3b6a7f0864ad12d0b585d6014657bda8163', id: this.getTitleId(), class: "pn-card-label" }, this.label)), h("slot", { key: '9500f8d69acd614b628fe97a8a1a3fe36ee0e64e', name: "header" })), h("section", { key: '8ace8af3b532dadaf129ffe12d6159a6e9c4820e', class: "pn-card-section" }, !!this.text && h("p", { key: 'ac162dbd6fd940e3a1b87b38ffa1acdb8dbfab76', class: "pn-card-section-paragraph" }, this.text), h("slot", { key: '814238314b9b5e77e6f7eb1c044016eb59f0d23b' })), h("nav", { key: '22cd78b16c68c5a0449223ad12c3bf756642928a', class: "pn-card-navigation" }, this.showHref() && (h("a", { key: '6fbfd640bdc555f272fb1cf72b27525fbb0e0e8f', class: "pn-card-link", href: this.href, target: this.target, rel: this.rel, "aria-labelledby": this.getLabelledby(), onClick: event => this.handleClick(event), onFocus: event => this.handleFocus(event), onBlur: event => this.handleFocus(event) }, this.hrefLabel, h("pn-icon", { key: '263e2160a76fc5258a44aa40bc6d52df8ec25086', color: "blue700", icon: this.getIcon() }))), h("slot", { key: 'edfeca3a4eb44e246a199985577355f570356258', name: "navigation" }))))));
    }
    static get is() { return "pn-card"; }
    static get originalStyleUrls() {
        return {
            "$": ["pn-card.scss"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["pn-card.css"]
        };
    }
    static get properties() {
        return {
            "label": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Headline of the card. Will act as label for the link if there is no `href-label` set."
                },
                "attribute": "label",
                "reflect": false
            },
            "labelTag": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "'h2' | 'h3' | 'h4' | 'h5' | 'h6' | 'p'",
                    "resolved": "\"h2\" | \"h3\" | \"h4\" | \"h5\" | \"h6\" | \"p\"",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "The label HTML tag. Default is `h3`."
                },
                "attribute": "label-tag",
                "reflect": false,
                "defaultValue": "'h3'"
            },
            "overline": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "Set a smaller text above the `label` text."
                },
                "attribute": "overline",
                "reflect": false
            },
            "text": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "Text content of the card."
                },
                "attribute": "text",
                "reflect": false
            },
            "cardId": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "Set a HTML id for the card. Optional and not required."
                },
                "attribute": "card-id",
                "reflect": false,
                "defaultValue": "null"
            },
            "horizontal": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [{
                            "name": "category",
                            "text": "Features"
                        }],
                    "text": "Uee the horizontal card layout."
                },
                "attribute": "horizontal",
                "reflect": false,
                "defaultValue": "false"
            },
            "reverse": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [{
                            "name": "category",
                            "text": "Features"
                        }],
                    "text": "Reverse the order of which the image will wrap."
                },
                "attribute": "reverse",
                "reflect": false,
                "defaultValue": "false"
            },
            "aspectRatio": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string | '3/3' | '16/9'",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [{
                            "name": "see",
                            "text": "{@link https://developer.mozilla.org/en-US/docs/Web/CSS/aspect-ratio CSS documentation.}"
                        }, {
                            "name": "category",
                            "text": "Features"
                        }],
                    "text": "Select image aspect ratio. Example: '3/3', '16/9'."
                },
                "attribute": "aspect-ratio",
                "reflect": false,
                "defaultValue": "''"
            },
            "href": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [{
                            "name": "category",
                            "text": "Href"
                        }],
                    "text": "The card link."
                },
                "attribute": "href",
                "reflect": false
            },
            "hrefLabel": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [{
                            "name": "category",
                            "text": "Href"
                        }],
                    "text": "The link text."
                },
                "attribute": "href-label",
                "reflect": false
            },
            "target": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [{
                            "name": "category",
                            "text": "Href"
                        }],
                    "text": "The target attribute of the link."
                },
                "attribute": "target",
                "reflect": false
            },
            "rel": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [{
                            "name": "category",
                            "text": "Href"
                        }],
                    "text": "The rel attribute of the link."
                },
                "attribute": "rel",
                "reflect": false,
                "defaultValue": "'noopener noreferrer'"
            },
            "icon": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [{
                            "name": "category",
                            "text": "Href"
                        }],
                    "text": "The link icon. Defaults to `arrow_right` or `open_in_new` if `target=\"_blank\"`."
                },
                "attribute": "icon",
                "reflect": false,
                "defaultValue": "null"
            }
        };
    }
    static get states() {
        return {
            "visibleOutline": {}
        };
    }
    static get events() {
        return [{
                "method": "pnCard",
                "name": "pnCard",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": "Emitted when you click on the card link (if you use the `href` prop)."
                },
                "complexType": {
                    "original": "{ click: MouseEvent }",
                    "resolved": "{ click: MouseEvent; }",
                    "references": {
                        "MouseEvent": {
                            "location": "global",
                            "id": "global::MouseEvent"
                        }
                    }
                }
            }];
    }
    static get elementRef() { return "hostElement"; }
    static get watchers() {
        return [{
                "propName": "cardId",
                "methodName": "watchCardId"
            }];
    }
}
//# sourceMappingURL=pn-card.js.map
