import { EventEmitter } from '../../../../stencil-public-runtime';
/**
 * Use this row component inside a `pn-accordion` to create an accordion group.
 *
 * **Note**: you can use the `pn-accordion-row` without the parent accordion.
 * But you will have to style the gap between each row.
 *
 * @slot label - Include your own HTML as the label.
 * ```
 * <h3 slot="label">Custom title</h3>
 * ```
 */
export declare class PnAccordionRow {
    details: HTMLDetailsElement;
    summary: HTMLElement;
    content: HTMLDivElement;
    animation: Animation;
    hostElement: HTMLElement;
    isClosing: boolean;
    isExpanding: boolean;
    /** The label/title of the accordion row, you can also pass a slot with the name "label" if you want to put custom HTML content in there. */
    label: string;
    /** The open/close status of the accordion row. */
    state?: boolean;
    /** Optional unique id for the `summary` element. @category ID */
    buttonid?: string;
    /** Optional unique id for the `div` element containing the content. @category ID */
    contentid?: string;
    /** Optional prop that removes the default white background on the accordion row */
    transparent: boolean;
    /** Dispatched every time the row is toggled. Includes the row element and the boolean `state` prop. */
    togglerow: EventEmitter<{
        element: HTMLElement;
        state: Boolean;
    }>;
    /** Internal function for closing rows when using the `single` prop on the `pn-accordion`. */
    handleRowState(event: CustomEvent): void;
    componentWillLoad(): void;
    toggleOpen(open?: boolean): void;
    clickHandler(e: MouseEvent): void;
    openAccordion(): void;
    closeAccordion(): void;
    animate(open: boolean, startHeight: string, endHeight: string): void;
    animationFinish(open: boolean): void;
    cancelAnimations(): void;
    render(): any;
}
