import type { PnLanguages } from "../../../index";
import { EventEmitter } from '../../../stencil-public-runtime';
/**
 * This component is able to fill many roles of a classic toast.
 * It has 4 different colors, a temporary state, hide button, icon and illustration support.
 *
 * The `pn-toast` will expand to its parent containers full width.
 * Either limit the parent width or set a CSS rule to your specific width if needed.
 */
export declare class PnToast {
    toast: HTMLOutputElement;
    button: HTMLButtonElement;
    animation: Animation;
    hostElement: HTMLElement;
    isClosing: boolean;
    isExpanding: boolean;
    hasSlottedContent: boolean;
    /**
     * Set a title for the toast. Requires the `text` prop in order to work.
     * @description Can be used together with slotted content.
     */
    heading?: string;
    /**
     * Set a paragraph of text for the toast.
     * @description Can be used together with slotted content.
     */
    text?: string;
    /** Give the toast a HTML ID. */
    toastId?: string;
    /**
     * Default color is blue, you also have the option of success (green), warning (orange) and error (red).
     * @category Visual
     */
    appearance?: '' | 'success' | 'warning' | 'error';
    /**
     * This will apply a shadow and border to the toast.
     * @category Visual
     */
    temporary: boolean;
    /**
     * Set an SVG icon.
     * @category Visual
     */
    icon?: string;
    /**
     * Set an SVG illustration.
     * @category Visual
     */
    illustration?: string;
    /**
     * Control the visibility of the toast. If the `closable` prop is active, the toast will set the `hide` prop on its own.
     * @see {@link closable}
     * @category Features
     */
    hide: boolean;
    /**
     * Show close button.
     * @category Features
     */
    closable: boolean;
    /**
     * Manually set the language, only needed if the `closable` prop is enabled.
     * @see {@link closable}
     * @category Features
     */
    language?: PnLanguages;
    handleHide(): CustomEvent<boolean>;
    /** Event fired when the close button is pressed. */
    close: EventEmitter<boolean>;
    /**
     * This event is fired when the toast is fully hidden after the animation is finished.
     * Triggers from the close button or if the prop `hide` is set to true.
     **/
    hidden: EventEmitter<boolean>;
    componentWillLoad(): Promise<void>;
    componentDidLoad(): void;
    private getRect;
    private openToast;
    private closeToast;
    private animateToast;
    private animationFinish;
    private cancelAnimations;
    private handleClick;
    private getIcon;
    private getRole;
    private showIcon;
    private showIllustration;
    private showTitle;
    private translate;
    private hideToast;
    render(): any;
}
