/**
 * The `pn-checkbox` is built with a native `input[type="checkbox"]` in the background.
 * This means you can use native events to listen to the changes.
 *
 * @nativeChange Use the `change` event to listen when the checkbox state is being toggled.
 */
export declare class PnCheckbox {
    id: string;
    idHelpertext: string;
    hostElement: HTMLElement;
    /** The checkbox label */
    label?: string;
    /** This will be emitted on change and input, like a native checkbox */
    value: string;
    /** The name of the checkbox group */
    name: string;
    /** Check the radio button. */
    checked: boolean;
    /** This adds an optional helpertext element under the label */
    helpertext?: string;
    /** A unique HTML ID for the checkbox. */
    checkboxid: string;
    /** Disable the radio button. @category State */
    disabled: boolean;
    /** Set the checkbox as required. @category State */
    required: boolean;
    /** If set to true, color scheme will turn red, indicating that there is an issue or incorrect input related the checkbox. @category State */
    invalid: boolean;
    /** Sets the checkbox to an indeterminate state, allowing for a mixed or intermediate checkbox state. @category State */
    indeterminate: boolean;
    /** If set to true, this checkbox turns into a checkbox-tile. @category Tile */
    tile: boolean;
    /** Add an icon on the right of your checkbox tile. The `tile` prop must be `true` for the icon to work. @category Tile */
    icon?: string;
    handleId(): void;
    handlechange(): void;
    componentWillLoad(): void;
    render(): any;
}
