/**
 * The fielset is a wrapper to give context and information about inputs. Most commonly, a set of radio/checkboxes.
 * However, you may include any type of input such as textareas, toggles and selects.
 */
export declare class PnFieldset {
    mo: MutationObserver;
    id: string;
    idHelpertext: string;
    hostElement: HTMLElement;
    /**
     * The legend provides a caption for the fieldset group.
     * This should be a question or heading that describes the inputs/fields.
     */
    legend: string;
    /** Text message underneath the legend for more instruction or hints on how to fill in controls correctly. */
    helpertext?: string;
    /** Give the fieldset a custom HTML id. */
    fieldsetId: string;
    /**
     * The id of the form you want the fieldset to be part of.
     * If you want the inputs inside to be associated with a specific form, you need to set on those elements directly.
     */
    form?: string;
    /** Give the fieldset a HTML name. */
    name?: string;
    /** Disable all of the inputs inside of the fieldset. */
    disabled: boolean;
    /** Set the fieldset as `invalid`, will add red error styles. */
    invalid: boolean;
    /** Error message, applies warning styles and icon. */
    error?: string;
    handleId(): void;
    componentWillLoad(): void;
    componentDidLoad(): void;
    componentDidRender(): void;
    hasError(): boolean;
    getSymbol(): string;
    render(): any;
}
