/**
 * The `pn-radio-button` is built with a native `input[type="radio"]` in the background.
 * This means you can use native events to listen to the changes.
 *
 * @nativeChange Use the `change` event to listen when the radio state is being changed.
 */
export declare class PnRadioButton {
    id: string;
    idHelper: string;
    hostElement: HTMLElement;
    /** The radio button label */
    label?: string;
    /** This will be emitted on `change` and `input`, like a native radio button (required)*/
    value: string;
    /** The name of the radio button group that will hold this button, like a native radio button (required) */
    name: string;
    /** Check the radio button */
    checked: boolean;
    /** With this prop you can add an optional helper text element to radio button. */
    helpertext?: string;
    /** Give the radio button a custom ID */
    radioid: string;
    /** Disable the radio button. @category State */
    disabled?: boolean;
    /** Set the radio button as required. @category State */
    required?: boolean;
    /** Trigger the red error state. @category State */
    invalid?: boolean;
    /** Turn this radio-button into a radio-tile. @category Tile */
    tile?: boolean;
    /** Add an icon on the right of your radio tile. The `tile` prop must be `true` for the icon to work. @category Tile */
    icon?: string;
    handleId(): void;
    componentWillLoad(): void;
    render(): any;
}
