import { EventEmitter } from '../../../stencil-public-runtime';
import type { PnLanguages } from "../../../globals/types";
export declare class PnSearchField {
    id: string;
    searchElement: HTMLInputElement;
    hostElement: HTMLElement;
    /** Provide an aria-label for the search field. */
    label: string;
    /** Set the value of the search field. */
    value: string;
    /** Set a search field placeholder. */
    placeholder?: string;
    /** Set a unique ID for the search input */
    searchid: string;
    /** Set HTML name of the search input. */
    name?: string;
    /** Allow the browser to autocomplete the search field. */
    autocomplete?: string;
    /** Point to a datalist element with this id. */
    list?: string;
    /** Override the pntopbar language. */
    language?: PnLanguages;
    /** Disable the search field. @category State */
    disabled: boolean;
    /** Set the search field as required. @category State */
    required: boolean;
    /** Display loading animation. @category State */
    loading: boolean;
    /** Button type, options are `none` for no button, `icon` for a labelless button with just a search icon and `icon-inline` for a search button inside of the search field (this last option disables the clear field button). @category Button */
    button: '' | 'none' | 'icon' | 'icon-inline';
    /** Label for the button element. @category Button */
    buttonLabel?: string;
    /** Light instead of dark search button. @category Button */
    buttonLight: boolean;
    /** This is emitted on search submission both with keyboard and mouse. */
    search: EventEmitter<string>;
    /** Custom event that handles both clearing and input to have the option of just binding listeners to one event instead of two. */
    update: EventEmitter<string>;
    inputHandler(): void;
    componentWillLoad(): Promise<void>;
    translate(prop: string): any;
    emitSearch({ click, button }: {
        click?: MouseEvent;
        button?: KeyboardEvent;
    }): void;
    setVal(e: InputEvent): void;
    clearInput(): void;
    getClassNames(): string;
    render(): any;
}
