/**
 * The `pn-textarea` is built with a native `textarea`.
 * This means you can use native events to listen to the input.
 *
 * @nativeInput Use the `input` event to listen to content being modified by the user.
 */
export declare class PnTextarea {
    id: string;
    idHelper: string;
    hostElement: HTMLElement;
    /** The textarea content */
    content: number;
    /** The label describing the textarea. */
    label: string;
    /** The textarea content, do not provide slotted content. */
    value: string;
    /** Helper text that will appear underneath the textarea. Will be overwritten if you set an `error` string */
    helpertext?: string;
    /** A unique ID connecting the element to the label. @category HTML Textarea */
    textareaid?: string;
    /** HTML name. @category HTML Textarea */
    name?: string;
    /** Set the associated form. @category HTML Textarea*/
    form?: string;
    /** Set the row count for the textarea. @category HTML Textarea */
    rows?: number;
    /** Set the col count for the textarea. @category HTML Textarea */
    cols?: number;
    /** Set the wrap control. @category HTML Textarea */
    wrap?: string;
    /** The maximum number of characters the user should be able to add, also adds a visible counter. @category HTML Textarea */
    maxlength?: number;
    /** Allow the browser to autocomplete the textarea. @category HTML Textarea */
    autocomplete?: string;
    /** Allow the browser to spellcheck the textarea. @category HTML Textarea */
    spellcheck: boolean;
    /** Placeholder for the textarea. @category HTML Textarea */
    placeholder?: string;
    /** Allow the user to resize the textarea vertically. Handle width in your own layout. @category HTML Textarea */
    resize?: boolean;
    /** Make the textarea required. @category HTML Textarea */
    required?: boolean;
    /** Set the textarea as `valid`, will make the Label and focus rings green. @category State */
    valid?: boolean;
    /** Set the textarea as `invalid`, will make the Label and focus rings red. @category State */
    invalid?: boolean;
    /** Same as `invalid`, but will display the string as an error message under the textarea. @category State */
    error?: string;
    /** Disable the textarea. @category State */
    disabled?: boolean;
    /** Make the textarea readonly. @category State */
    readonly?: boolean;
    componentWillLoad(): void;
    setVal(event: Event): void;
    hasError(): boolean;
    hasMessage(): boolean;
    render(): any;
}
