/**
 * The `pn-toggle-switch` is built with a native `input[type="checkbox"]` in the background.
 * This means you can use native events to listen to the changes.
 *
 * @nativeChange Use the `change` event to listen when the switch state is being toggled.
 *
 * @slot helpertext - Set the helpertext with a slot instead of prop. Use a `span` element as wrapper.
 * Only use if you need HTML content, such as a link.
 */
export declare class PnToggleSwitch {
    private readonly id;
    private idHelper;
    hostElement: HTMLElement;
    /** A label for the toggle switch. */
    label: string;
    /** Provide a helpertext for the toggle switch. */
    helpertext?: string;
    /** Precheck the toggle. */
    checked: boolean;
    /** Set a unique HTML id. */
    toggleid: string;
    /** HTML toggle name. @category HTML */
    name?: string;
    /** HTML toggle value. @category HTML */
    value?: string;
    /** Make the toggle smaller. @category Visual */
    small: boolean;
    /** Make the toggle larger. @category Visual */
    large: boolean;
    /** Disable the toggle. @category State */
    disabled: boolean;
    /** Set the loading state. @category State */
    loading: boolean;
    handleHelperId(): void;
    componentWillLoad(): void;
    private hasHelpertextProp;
    private hasHelpertextSlot;
    private showHelpertext;
    private describedBy;
    render(): any;
}
