import { EventEmitter } from '../../../stencil-public-runtime';
/**
 * The `pn-tile` is a navigational element that is intended to be accompanied by an illustration.
 *
 * It is very important that you use the `label` and `url`. This component renders an `a` element if the URL prop is set,
 * so you do not need to wrap or nest the tile in another `a` element. Doing so makes the component inaccessible.
 *
 * @slot illustration - Set a custom SVG. We recommend you use the `pn-illustration` component.
 * This is the same as the `illustration` prop.
 */
export declare class PnTile {
    private mo;
    private tile;
    private illustrationSlot;
    visibleOutline: boolean;
    hostElement: HTMLElement;
    /** Label of the link. This is required for the component to be accessible. */
    label: string;
    /** Set a string of text for the tile. Same as the default slot. */
    text?: string;
    /** The link of the tile. This is required for the component to be accessible. @category href */
    url: string;
    /** The target attribute of the link. @category href */
    target?: string;
    /** The rel attribute of the link. @category href */
    rel?: string;
    /** The SVG content of an illustration. @category Image */
    illustration?: string;
    /** The SVG content of a decorative icon. @category Image */
    icon?: string;
    /** Use the horizontal tile. @category Layout */
    horizontal?: boolean;
    /**
     * Emitted when the link is clicked. Use the `click` property to `preventDefault`
     * if you wish to perform the navigation programmatically.
     **/
    pnTile: EventEmitter<{
        click: MouseEvent;
    }>;
    connectedCallback(): void;
    disconnectedCallback(): void;
    private isExternal;
    private showIcon;
    private showPropIllustration;
    private showSlotIllustration;
    private showImage;
    private handleFocus;
    private clickHandler;
    render(): any;
}
